#
# spec file for package gstreamer-plugins-rs
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name gstreamer-plugins-rs
%define gst_branch 1.0
%global rustflags '-Clink-arg=-Wl,-z,relro,-z,now'
# Disable csound for now, bring issue upstream
#%%global __requires_exclude pkgconfig\\(csound\\)
%define req_rust_ver 1.56

Name:           gstreamer-plugins-rs
Version:        0.8.2
Release:        150400.3.3.1
Summary:        GStreamer Streaming-Media Framework Plug-Ins
License:        LGPL-2.1-or-later
Group:          Productivity/Multimedia/Other
URL:            https://gstreamer.freedesktop.org/

Source0:        %{_name}-%{version}.tar.xz
Source1:        vendor.tar.xz
Source2:        cargo_config
Source3:        gstreamer-plugins-rs.appdata.xml
Patch0:         0001-feath2-add-max_header_list_size.patch
Patch1:         0002-feath2-add-max_header_list_size-rename.patch

BuildRequires:  cargo%{req_rust_ver}
BuildRequires:  cargo-c
BuildRequires:  clang
# Disable csound for now, bring issue upstream
#BuildRequires:  csound-devel
BuildRequires:  llvm
BuildRequires:  git
BuildRequires:  meson >= 0.47.0
BuildRequires:  nasm
BuildRequires:  pkgconfig
BuildRequires:  rust%{req_rust_ver}
BuildRequires:  pkgconfig(cairo) >= 1.10.0
BuildRequires:  pkgconfig(dav1d)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-base-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libsodium)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(pango)
Requires:       gstreamer
Requires:       gstreamer-plugins-base
Enhances:       gstreamer

%description
GStreamer is a streaming media framework based on graphs of filters
that operate on media data. Applications using this library can do
anything media-related, from real-time sound processing to playing
videos. Its plug-in-based architecture means that new data types or
processing capabilities can be added simply by installing new
plug-ins.

%package devel
Summary:        GStreamer Streaming-Media Framework Plug-Ins development files
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
#Requires:       csound-devel

%description devel
GStreamer is a streaming media framework based on graphs of filters
that operate on media data. Applications using this library can do
anything media-related, from real-time sound processing to playing
videos. Its plug-in-based architecture means that new data types or
processing capabilities can be added simply by installing new
plug-ins.

This package contains the pkgconfig development files for the rust
plugins.

%prep
%autosetup -n %{_name}-%{version} -N

%setup -q -D -T -a 1
%define cargo_registry $(pwd)/vendor
mkdir .cargo
cp %{SOURCE2} .cargo/config
pushd vendor/hyper
%patch0 -p1
%patch1 -p1
sed -i -e "s/128dbe1443b3855a3dd48f1ff61d3aa4cb61ad38f9b8503b37d0d728fba880b5/f8810ae71c7ae5664f5c811a55cad6d0e0716232eeedc63bb76cb6261084d01c/" .cargo-checksum.json
sed -i -e "s/f944b70affd4db52b053c4f5765c118c3ae0cd2e42a3bcdb53f3f05b5d0771f9/950e826f6c5e2352203e16a9cd92c5278a5a60d03ef8d3ca885358a1946e84e4/" .cargo-checksum.json
popd


%build
# Disable csound for now, bring issue upstream
#export CSOUND_LIB_DIR=%%{_libdir}
export RUSTFLAGS=%{rustflags}

%meson \
	-Ddav1d=auto \
	-Dsodium=system \
	-Dcsound=disabled \
	%{nil}
%meson_build

%install
export RUSTFLAGS=%{rustflags}
%meson_install
mkdir -p %{buildroot}%{_datadir}/appdata
cp %{SOURCE3} %{buildroot}%{_datadir}/appdata/

%files
%license LICENSE-APACHE LICENSE-LGPLv2 LICENSE-MIT
%doc README.md
%dir %{_libdir}/gstreamer-%{gst_branch}
%{_libdir}/gstreamer-%{gst_branch}/libgstcdg.so
%{_libdir}/gstreamer-%{gst_branch}/libgstclaxon.so
# Disable csound for now, bring issue upstream
#%%{_libdir}/gstreamer-%%{gst_branch}/libgstcsound.so
%{_libdir}/gstreamer-%{gst_branch}/libgstrsdav1d.so
%{_libdir}/gstreamer-%{gst_branch}/libgstfallbackswitch.so
%{_libdir}/gstreamer-%{gst_branch}/libgstgif.so
%{_libdir}/gstreamer-%{gst_branch}/libgsthsv.so
%{_libdir}/gstreamer-%{gst_branch}/libgstlewton.so
%{_libdir}/gstreamer-%{gst_branch}/libgstrav1e.so
%{_libdir}/gstreamer-%{gst_branch}/libgstreqwest.so
%{_libdir}/gstreamer-%{gst_branch}/libgstrsaudiofx.so
%{_libdir}/gstreamer-%{gst_branch}/libgstrsclosedcaption.so
%{_libdir}/gstreamer-%{gst_branch}/libgstrsfile.so
%{_libdir}/gstreamer-%{gst_branch}/libgstrsflv.so
%{_libdir}/gstreamer-%{gst_branch}/libgstrsjson.so
%{_libdir}/gstreamer-%{gst_branch}/libgstrspng.so
%{_libdir}/gstreamer-%{gst_branch}/libgstrsregex.so
%{_libdir}/gstreamer-%{gst_branch}/libgstrstextwrap.so
%{_libdir}/gstreamer-%{gst_branch}/libgstrswebp.so
%{_libdir}/gstreamer-%{gst_branch}/libgstrusoto.so
%{_libdir}/gstreamer-%{gst_branch}/libgstsodium.so
%{_libdir}/gstreamer-%{gst_branch}/libgstthreadshare.so
%{_libdir}/gstreamer-%{gst_branch}/libgsttogglerecord.so
%{_libdir}/gstreamer-%{gst_branch}/libgstffv1.so
%{_libdir}/gstreamer-%{gst_branch}/libgstfmp4.so
%{_libdir}/gstreamer-%{gst_branch}/libgstgtk4.so
%{_libdir}/gstreamer-%{gst_branch}/libgsthlssink3.so
%{_libdir}/gstreamer-%{gst_branch}/libgstspotify.so
%{_libdir}/gstreamer-%{gst_branch}/libgsttextahead.so
%{_libdir}/gstreamer-%{gst_branch}/libgsturiplaylistbin.so
%{_libdir}/gstreamer-%{gst_branch}/libgstvideofx.so

%dir %{_datadir}/appdata
%{_datadir}/appdata/gstreamer-plugins-rs.appdata.xml

%files devel
%{_libdir}/pkgconfig/*.pc

%changelog
* Tue Jan  9 2024 alarrosa@suse.com
- Add patches from upstream to fix a possible denial of service
  in the vendored package hyper (bsc#1208556, CVE-2022-31394):
  * 0001-feath2-add-max_header_list_size.patch
  * 0002-feath2-add-max_header_list_size-rename.patch
- Force using rust 1.56 since rust was updated since the last time
  this package was built in SLE and the latest rust can't build
  this version of gstreamer-plugins-rs.
* Mon Feb 28 2022 bjorn.lie@gmail.com
- Update to version 0.8.2:
  * Update Cargo.lock
  * ci: Use correct gstreamer-rs images template
  * deny: Remove num-rational override
  * dav1ddec:
  - Use `AtomicRefCell` instead of `Mutex` for the state
  - Fix compilation after some API changes
  - Release input frames that immediately caused a decoding error
* Fri Feb  4 2022 bjorn.lie@gmail.com
- Update to version 0.8.1:
  * Update Cargo.lock
  * Update versions to 0.8.1
  * cdg: update image and cdg_renderer
  * gtk4: Attach main context receiver from the main context's
    thread
  * dav1ddec: Add 8/16 bit grayscale support
  * rav1enc: Support 8 bit grayscale input
  * dav1ddec: Require correct alignment and stream format when
    running with GStreamer 1.20
  * rav1enc: Include stream-format and alignment in the caps
  * dav1ddec: Clean up state tracking a bit
- Add automatic .changes generation to service, as upstream seems
  to not want to make release notes or changelogs.
* Wed Jan 19 2022 alarrosa@suse.com
- Add a BuildRequires: pkgconfig(libwebp) to fix loading
  libgstrswebp.so which was failing with an `undefined symbol:
  WebPAnimDecoderDelete` error.
* Tue Jan 18 2022 alarrosa@suse.com
- Increase the disk constraint since i586 builds take ~15.6 GB,
  s390x over 22 GB and other archs ~18.8 GB.
* Mon Jan 17 2022 alarrosa@suse.com
- Update to version 0.8.0:
  * No changelog provided by upstream
* Wed Nov 10 2021 bjorn.lie@gmail.com
- Disable csound plugin for now, mask all macros, BuildRequires and
  set option passed to meson to disabled (was auto), wait for
  upstream to fix the issues identified.
* Tue Nov  2 2021 bjorn.lie@gmail.com
- Filter out pkgconfig(csound) Requires, add manual csound-devel
  BuildRequires to devel package. csound-devel does not provide a
  .pc file so the autogenerated Requires on pkconfig(csound) is
  wrong.
* Tue Nov  2 2021 bjorn.lie@gmail.com
- Drop baselibs.conf, this is a new package, lets not build 32bit
  unless we have to.
* Sat Oct 16 2021 bjorn.lie@gmail.com
- No longer disabled LTO, drop macro.
* Sat Sep  4 2021 bjorn.lie@gmail.com
- Update to version 0.7.2:
- Switch service to using an explicit released tag.
- Drop 0001-Fix-cast-to-f64-so-it-builds-in-i586.patch: Fixed
  upstream.
* Mon Apr 19 2021 alarrosa@suse.com
- Update to 0.6.0+git20210412.c3fb55f
- Add patch to fix build in the i586 architecture
  (Submitted in glfo#gstreamer/gst-plugins-rs#502):
  * 0001-Fix-cast-to-f64-so-it-builds-in-i586.patch
* Thu Dec 24 2020 bjorn.lie@gmail.com
- Enable build of dav1d plugin, do this via:
  + Disable LTO via macro.
  + Add clang and pkgconfig(dav1d) BuildRequires.
  + No longer pass dav1d=disabled to meson, nor remove dav1d from
    cargo.toml via sed call.
- Add pkgconfig(libsodium) BuildRequires and pass sodium=system to
  meson, do not use package internal version of sodium.
- Drop pkgconfig(gtk+-3.0) BuildRequires, not needed.
- Add pkgconfig(pango) BuildRequires: Mandatory, previously pulled
  in by pkgconfig(gtk+-3.0), and add optional nasm BuildRequires.
- Drop gcc-c++ BuildRequires, no longer needed, nor used.
- Replace llvm-devel with llvm BuildRequires, this is sufficent.
- Do general cleanup of spec, make package ready for submit to TW.
  Use normal meson macros.
- Add _constraints, ensure the build have enough harddisk space.
* Tue Dec  1 2020 alarrosa@suse.com
- Update to git version 0.6.0+git20201201.58786fa
- Use obs-service-cargo_vendor in the _service file and replace
  vendor-cargo-config with cargo_config
- Enable the build of sodium and threadshare plugins
- Remove special Cargo.lock source file which is not needed anymore
* Wed Oct 28 2020 alarrosa@suse.com
- Fix version, since the initial release wasn't 1.18.0 but 0.6.0
- Update to git version 0.6.0+git20201026.d16e7d1
* Sat Oct 24 2020 dimstar@opensuse.org
- Use %%_vpath_builddir instead of hardcoded 'build' directory name:
  meson allows for the path to be changed.
* Wed Sep 16 2020 alarrosa@suse.com
- Initial release of gstreamer-plugins-rs 1.18.0
